/* gnome-rdp
 * Copyright (C) 2005-2006 Balazs Varkonyi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using Gtk;
using Gdk;
using Glade;
using Mono.Unix;
using GnomeRDP;

namespace GnomeRDP
{
	public class AboutDialog : GladeDialog
	{
#pragma warning disable 0649
		[Widget]Label 		lbVersion;
		[Widget]Gtk.Image 	iLogo;
#pragma warning restore 0649
		
		public AboutDialog() : base("dlgAbout")
		{
			lbVersion.Text = Catalog.GetString("Version") + " " + Defines.VERSION;
			iLogo.Pixbuf = Gdk.Pixbuf.LoadFromResource("title.png"); 
		}
		
		public void Run()
		{
			this.Dialog.Run();
			this.Dialog.Destroy();
		}
	}	
}